#ifndef GNUMERIC_WORKBOOK_OBJECT_TOOLBAR_H
#define GNUMERIC_WORKBOOK_OBJECT_TOOLBAR_H

#include "gnumeric.h"
#include "workbook-control-gui.h"

void workbook_create_object_toolbar (WorkbookControlGUI *wb);

#endif /* GNUMERIC_WORKBOOK_OBJECT_TOOLBAR_H */
